from PySide2 import QtCore, QtWidgets, QtWebEngineWidgets, QtGui
from OpenGL import GL
import os

class Ui_Library(object):
    def setupUI(self, Library, connection):
        self.gridLayout = QtWidgets.QGridLayout(Library)
        self.gridLayout.setObjectName("gridLayout")

        self.splitter = QtWidgets.QSplitter(Library)
        self.splitter.setObjectName("splitter")
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setHandleWidth(15)
        #self.splitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter.png")+");}");

        self.inputLayoutWidget = QtWidgets.QWidget(self.splitter)
        self.inputLayoutWidget.setObjectName("inputLayoutWidget")

        self.inputLayout = QtWidgets.QGridLayout(self.inputLayoutWidget)
        self.inputLayout.setObjectName("inputLayout")
        self.inputLayout.setContentsMargins(0, 0, 0, 0)

        self.libraryGroupBox = QtWidgets.QGroupBox(self.inputLayoutWidget)
        self.libraryGroupBox.setObjectName("libraryGroupBox")
        self.libraryGroupBox.setTitle("Library generation")

        self.libraryLayout = QtWidgets.QGridLayout(self.libraryGroupBox)
        self.libraryLayout.setObjectName("libraryLayout")

        self.titleLabel = QtWidgets.QLabel(self.libraryGroupBox)
        self.titleLabel.setObjectName("titleLabel")
        self.titleLabel.setText("Job title")
        self.libraryLayout.addWidget(self.titleLabel, 0, 0, 1, 1)
        self.titleLine = QtWidgets.QLineEdit(self.libraryGroupBox)
        self.titleLine.setObjectName("titleLine")
        self.titleLine.setFixedWidth(150)
        self.libraryLayout.addWidget(self.titleLine, 0, 1, 1, 1)

        self.runLabel = QtWidgets.QLabel(self.libraryGroupBox)
        self.runLabel.setObjectName("runLabel")
        self.runLabel.setText("Run in")
        self.libraryLayout.addWidget(self.runLabel, 1, 0, 1, 1)
        self.runValue = QtWidgets.QComboBox(self.libraryGroupBox)
        self.runValue.setObjectName("runValue")
        self.runValue.addItems(["multiprocessing","local_grid","supercomputer","remote_grid"])
        self.libraryLayout.addWidget(self.runValue, 1, 1, 1, 1)

        self.gridLabel = QtWidgets.QLabel(self.libraryGroupBox)
        self.gridLabel.setObjectName("gridLabel")
        self.gridLabel.setText("Configuration file")
        self.gridLabel.setEnabled(False)
        self.libraryLayout.addWidget(self.gridLabel, 1, 2, 1, 1)
        self.gridLine = QtWidgets.QLineEdit(self.libraryGroupBox)
        self.gridLine.setObjectName("gridLine")
        self.gridLine.setEnabled(False)
        self.libraryLayout.addWidget(self.gridLine, 1, 3, 1, 1)
        self.gridLoad = QtWidgets.QPushButton(self.libraryGroupBox)
        self.gridLoad.setObjectName("gridLoad")
        self.gridLoad.setText("Browse")
        self.gridLoad.setEnabled(False)
        self.libraryLayout.addWidget(self.gridLoad, 1, 4, 1, 1)

        self.testCheck = QtWidgets.QCheckBox(self.libraryGroupBox)
        self.testCheck.setObjectName("testCheck")
        self.testCheck.setText("Testing parameterization with a limited number of models")
        self.libraryLayout.addWidget(self.testCheck, 2, 0, 1, 4)

        self.line = QtWidgets.QFrame(self.libraryGroupBox)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.libraryLayout.addWidget(self.line, 0, 5, 3, 1)

        self.alphaLabel = QtWidgets.QLabel(self.libraryGroupBox)
        self.alphaLabel.setObjectName("alphaLabel")
        self.alphaLabel.setText("strictness alpha")
        self.libraryLayout.addWidget(self.alphaLabel, 0, 6, 1, 1)
        self.alphaSlider = QtWidgets.QSlider(self.libraryGroupBox)
        self.alphaSlider.setObjectName("alphaSlider")
        self.alphaSlider.setOrientation(QtCore.Qt.Horizontal)
        self.alphaSlider.setMinimum(0)
        self.alphaSlider.setMaximum(100)
        self.alphaSlider.setSingleStep(10)
        self.alphaSlider.setValue(50)
        self.libraryLayout.addWidget(self.alphaSlider, 0, 7, 1, 1)
        self.alphaValue = QtWidgets.QLabel(self.libraryGroupBox)
        self.alphaValue.setObjectName("valueAlpha")
        self.alphaValue.setText("0.50")
        self.libraryLayout.addWidget(self.alphaValue, 0, 8, 1, 1)

        self.betaLabel = QtWidgets.QLabel(self.libraryGroupBox)
        self.betaLabel.setObjectName("betaLabel")
        self.betaLabel.setText("strictness beta")
        self.libraryLayout.addWidget(self.betaLabel, 1, 6, 1, 1)
        self.betaSlider = QtWidgets.QSlider(self.libraryGroupBox)
        self.betaSlider.setObjectName("betaSlider")
        self.betaSlider.setOrientation(QtCore.Qt.Horizontal)
        self.betaSlider.setMinimum(0)
        self.betaSlider.setMaximum(100)
        self.betaSlider.setSingleStep(10)
        self.betaSlider.setValue(30)
        self.libraryLayout.addWidget(self.betaSlider, 1, 7, 1, 1)
        self.betaValue = QtWidgets.QLabel(self.libraryGroupBox)
        self.betaValue.setObjectName("betaValue")
        self.betaValue.setText("0.30")
        self.libraryLayout.addWidget(self.betaValue, 1, 8, 1, 1)

        self.inputLayout.addWidget(self.libraryGroupBox, 0, 0, 1, 2)

        self.databaseGroupBox = QtWidgets.QGroupBox(self.inputLayoutWidget)
        self.databaseGroupBox.setObjectName("databaseGroupBox")
        self.databaseGroupBox.setTitle("Select database")

        self.databaseLayout = QtWidgets.QGridLayout(self.databaseGroupBox)
        self.databaseLayout.setObjectName("databaseLayout")

        self.pdbRadio = QtWidgets.QRadioButton(self.databaseGroupBox)
        self.pdbRadio.setObjectName("pdbRadio")
        self.pdbRadio.setText("Pdb directory")
        self.pdbRadio.setChecked(True)
        self.databaseLayout.addWidget(self.pdbRadio, 0, 0, 1, 1)
        self.pdbLine = QtWidgets.QLineEdit(self.databaseGroupBox)
        self.pdbLine.setObjectName("pdbLine")
        self.databaseLayout.addWidget(self.pdbLine, 0, 1, 1, 1)
        self.pdbLoad = QtWidgets.QPushButton(self.databaseGroupBox)
        self.pdbLoad.setObjectName("pdbLoad")
        self.pdbLoad.setText("Browse")
        self.databaseLayout.addWidget(self.pdbLoad, 0, 2, 1, 1)
        self.pdbDownload = QtWidgets.QPushButton(self.databaseGroupBox)
        self.pdbDownload.setObjectName("pdbDownload")
        self.pdbDownload.setText("Download PDB database")
        self.pdbDownload.setEnabled(connection)
        self.databaseLayout.addWidget(self.pdbDownload, 0, 3, 1, 1)

        self.seqRadio = QtWidgets.QRadioButton(self.databaseGroupBox)
        self.seqRadio.setObjectName("seqRadio")
        self.seqRadio.setText("Sequence")
        self.seqRadio.setEnabled(connection)
        self.databaseLayout.addWidget(self.seqRadio, 1, 0, 1, 1)
        self.seqLine = QtWidgets.QLineEdit(self.databaseGroupBox)
        self.seqLine.setObjectName("seqLine")
        self.seqLine.setEnabled(connection)
        self.databaseLayout.addWidget(self.seqLine, 1, 1, 1, 1)
        self.seqLoad = QtWidgets.QPushButton(self.databaseGroupBox)
        self.seqLoad.setObjectName("seqLoad")
        self.seqLoad.setText("Browse")
        self.seqLoad.setEnabled(connection)
        self.databaseLayout.addWidget(self.seqLoad, 1, 2, 1, 1)

        self.cathRadio = QtWidgets.QRadioButton(self.databaseGroupBox)
        self.cathRadio.setObjectName("cathRadio")
        self.cathRadio.setText("CATH ID")
        self.cathRadio.setEnabled(connection)
        self.databaseLayout.addWidget(self.cathRadio, 2, 0, 1, 1)
        self.cathLine = QtWidgets.QLineEdit(self.databaseGroupBox)
        self.cathLine.setObjectName("cathLine")
        self.cathLine.setEnabled(connection)
        self.databaseLayout.addWidget(self.cathLine, 2, 1, 1, 1)

        self.excludeCheck = QtWidgets.QCheckBox(self.libraryGroupBox)
        self.excludeCheck.setObjectName("excludeCheck")
        self.excludeCheck.setText("Exclude sequence with more than 90% identity")
        self.databaseLayout.addWidget(self.excludeCheck, 3, 0, 1, 2)
        self.excludeLine = QtWidgets.QLineEdit(self.databaseGroupBox)
        self.excludeLine.setObjectName("excludeLine")
        self.excludeLine.setEnabled(False)
        self.databaseLayout.addWidget(self.excludeLine, 3, 2, 1, 1)
        self.excludeLoad = QtWidgets.QPushButton(self.databaseGroupBox)
        self.excludeLoad.setObjectName("excludeLoad")
        self.excludeLoad.setText("Browse")
        self.excludeLoad.setEnabled(False)
        self.databaseLayout.addWidget(self.excludeLoad, 3, 3, 1, 1)

        self.inputLayout.addWidget(self.databaseGroupBox, 1, 0, 1, 1)

        self.templateGroupBox = QtWidgets.QGroupBox(self.inputLayoutWidget)
        self.templateGroupBox.setObjectName("templateGroupBox")
        self.templateGroupBox.setTitle("Create template")

        self.templateLayout = QtWidgets.QGridLayout(self.templateGroupBox)
        self.templateLayout.setObjectName("templateLayout")

        self.templateLabel = QtWidgets.QLabel(self.templateGroupBox)
        self.templateLabel.setObjectName("templateLabel")
        self.templateLabel.setText("Template PDB:")
        self.templateLayout.addWidget(self.templateLabel, 0, 0, 1, 1)
        self.templateLine = QtWidgets.QLineEdit(self.templateGroupBox)
        self.templateLine.setObjectName("templateLine")
        self.templateLayout.addWidget(self.templateLine, 0, 1, 1, 1)
        self.templateLoad = QtWidgets.QPushButton(self.templateGroupBox)
        self.templateLoad.setObjectName("templateLoad")
        self.templateLoad.setText("Browse")
        self.templateLayout.addWidget(self.templateLoad, 0, 2, 1, 1)
        self.templateCoot = QtWidgets.QPushButton(self.templateGroupBox)
        self.templateCoot.setObjectName("templateLoad")
        self.templateCoot.setText("Open coot")
        self.templateLayout.addWidget(self.templateCoot, 0, 3, 1, 1)

        self.inputLayout.addWidget(self.templateGroupBox, 1, 1, 1, 1)

        self.superpositionGroupBox = QtWidgets.QGroupBox(self.inputLayoutWidget)
        self.superpositionGroupBox.setObjectName("superpositionGroupBox")
        self.superpositionGroupBox.setTitle("Extraction and superposition")

        self.superpositionLayout = QtWidgets.QGridLayout(self.superpositionGroupBox)
        self.superpositionLayout.setObjectName("superpositionLayout")

        self.strictnessLayout = QtWidgets.QHBoxLayout()
        self.strictnessLayout.setObjectName("strictnessLayout")

        self.superpositionLayout.addLayout(self.strictnessLayout, 0, 0, 1, 5)

        self.superpositionWidget = QtWidgets.QWidget(self.superpositionGroupBox)
        self.superpositionWidget.setObjectName("superpositionWidget")
        self.superpositionWidgetLayout = QtWidgets.QGridLayout(self.superpositionWidget)
        self.superpositionWidgetLayout.setObjectName("superpositionWidgetLayout")
        self.superpositionWidgetLayout.setContentsMargins(0, 0, 0, 0)

        self.intraLabel = QtWidgets.QLabel(self.superpositionWidget)
        self.intraLabel.setObjectName("intraLabel")
        self.intraLabel.setText("Secondary structure match")
        self.superpositionWidgetLayout.addWidget(self.intraLabel, 0, 0, 1, 1)
        self.intraSpin = QtWidgets.QSpinBox(self.superpositionWidget)
        self.intraSpin.setObjectName("intraSpin")
        self.intraSpin.setMinimum(0)
        self.intraSpin.setMaximum(100)
        self.intraSpin.setSingleStep(10)
        self.intraSpin.setValue(95)
        self.superpositionWidgetLayout.addWidget(self.intraSpin, 0, 1, 1, 1)

        self.interLabel = QtWidgets.QLabel(self.superpositionWidget)
        self.interLabel.setObjectName("interLabel")
        self.interLabel.setText("Tertiary structure match")
        self.superpositionWidgetLayout.addWidget(self.interLabel, 1, 0, 1, 1)
        self.interSpin = QtWidgets.QSpinBox(self.superpositionWidget)
        self.interSpin.setObjectName("interSpin")
        self.interSpin.setMinimum(0)
        self.interSpin.setMaximum(100)
        self.interSpin.setSingleStep(10)
        self.interSpin.setValue(95)
        self.superpositionWidgetLayout.addWidget(self.interSpin, 1, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.superpositionWidgetLayout.addItem(spacerItem, 1, 2, 1, 1)

        self.superpositionLayout.addWidget(self.superpositionWidget, 0, 0, 1, 6)

        self.rmsdLabel = QtWidgets.QLabel(self.superpositionGroupBox)
        self.rmsdLabel.setObjectName("rmsdLabel")
        self.rmsdLabel.setText("Rmsd from")
        self.superpositionLayout.addWidget(self.rmsdLabel, 1, 0, 1, 1)
        self.rmsdLayout = QtWidgets.QHBoxLayout()
        self.rmsdLayout.setObjectName("rmsdLayout")
        self.rmsdLayout.setContentsMargins(0, 0, 0, 0)
        self.minRmsdValue = QtWidgets.QDoubleSpinBox(self.superpositionGroupBox)
        self.minRmsdValue.setObjectName("minRmsdValue")
        self.minRmsdValue.setMinimum(0)
        self.minRmsdValue.setMaximum(10)
        self.rmsdLayout.addWidget(self.minRmsdValue)
        self.rmsdToLabel = QtWidgets.QLabel(self.superpositionGroupBox)
        self.rmsdToLabel.setObjectName("rmsdToLabel")
        self.rmsdToLabel.setText("to")
        self.rmsdLayout.addWidget(self.rmsdToLabel)
        self.maxRmsdValue = QtWidgets.QDoubleSpinBox(self.superpositionGroupBox)
        self.maxRmsdValue.setObjectName("maxRmsdValue")
        self.maxRmsdValue.setMinimum(0)
        self.maxRmsdValue.setMaximum(10)
        self.maxRmsdValue.setValue(6)
        self.rmsdLayout.addWidget(self.maxRmsdValue)
        self.superpositionLayout.addLayout(self.rmsdLayout, 1, 1, 1, 1)

        self.representativeCheck = QtWidgets.QCheckBox(self.superpositionGroupBox)
        self.representativeCheck.setObjectName("representativeCheck")
        self.representativeCheck.setText("One model per pdb")
        self.superpositionLayout.addWidget(self.representativeCheck, 2, 0, 1, 2)           

        self.inputLayout.addWidget(self.superpositionGroupBox, 2, 0, 1, 1)

        self.clusterGroupBox = QtWidgets.QGroupBox(self.inputLayoutWidget)
        self.clusterGroupBox.setObjectName("clusterGroupBox")
        self.clusterGroupBox.setTitle("Clustering")
        self.clusterGroupBox.setCheckable(True)
        self.clusterGroupBox.setChecked(False)

        self.clusterLayout = QtWidgets.QGridLayout(self.clusterGroupBox)
        self.clusterLayout.setObjectName("clusterLayout")

        self.clusteringModeLabel = QtWidgets.QLabel(self.superpositionGroupBox)
        self.clusteringModeLabel.setObjectName("clusteringModeLabel")
        self.clusteringModeLabel.setText("Mode")
        self.clusterLayout.addWidget(self.clusteringModeLabel, 0, 0, 1, 1)         
        self.clusteringValue = QtWidgets.QComboBox(self.superpositionGroupBox)
        self.clusteringValue.setObjectName("clusteringValue")
        self.clusteringValue.addItems(["Group by rmsd","Random sampling","Group by rmsd range"])
        self.clusterLayout.addWidget(self.clusteringValue, 0, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.clusterLayout.addItem(spacerItem, 0, 2, 1, 1)

        self.rmsdModeWidget = QtWidgets.QWidget(self.superpositionGroupBox)
        self.rmsdModeWidget.setObjectName("rmsdModeWidget")
        self.rmsdModeWidgetLayout = QtWidgets.QGridLayout(self.rmsdModeWidget)
        self.rmsdModeWidgetLayout.setObjectName("rmsdModeWidgetLayout")
        self.rmsdModeWidgetLayout.setContentsMargins(0, 0, 0, 0)

        self.rmsdLabel = QtWidgets.QLabel(self.rmsdModeWidget)
        self.rmsdLabel.setObjectName("rmsdLabel")
        self.rmsdLabel.setText("Rmsd")
        self.rmsdModeWidgetLayout.addWidget(self.rmsdLabel, 0, 1, 1, 1) 
        self.rmsdValue = QtWidgets.QDoubleSpinBox(self.rmsdModeWidget)
        self.rmsdValue.setObjectName("rmsdValue")
        self.rmsdValue.setMinimum(0)
        self.rmsdValue.setMaximum(8)
        self.rmsdValue.setValue(1.5)
        self.rmsdValue.setSuffix(" A")
        self.rmsdModeWidgetLayout.addWidget(self.rmsdValue, 0, 2, 1, 1)

        self.clusterLayout.addWidget(self.rmsdModeWidget, 1, 0, 1, 2)

        self.samplingModeWidget = QtWidgets.QWidget(self.superpositionGroupBox)
        self.samplingModeWidget.setObjectName("samplingModeWidget")
        self.samplingModeWidget.hide()
        self.samplingModeWidgetLayout = QtWidgets.QGridLayout(self.samplingModeWidget)
        self.samplingModeWidgetLayout.setObjectName("samplingModeWidgetLayout")
        self.samplingModeWidgetLayout.setContentsMargins(0, 0, 0, 0)

        self.samplingLabel = QtWidgets.QLabel(self.samplingModeWidget)
        self.samplingLabel.setObjectName("samplingLabel")
        self.samplingLabel.setText("Number of clusters")
        self.samplingModeWidgetLayout.addWidget(self.samplingLabel, 0, 1, 1, 1) 
        self.samplingValue = QtWidgets.QSpinBox(self.samplingModeWidget)
        self.samplingValue.setObjectName("samplingValue")
        self.samplingValue.setMaximum(9999)
        self.samplingValue.setValue(7000)
        self.samplingModeWidgetLayout.addWidget(self.samplingValue, 0, 2, 1, 1)

        self.clusterLayout.addWidget(self.samplingModeWidget, 2, 0, 1, 2)

        self.rangeModeWidget = QtWidgets.QWidget(self.superpositionGroupBox)
        self.rangeModeWidget.setObjectName("rangeModeWidget")
        self.rangeModeWidget.hide()
        self.rangeModeWidgetLayout = QtWidgets.QGridLayout(self.rangeModeWidget)
        self.rangeModeWidgetLayout.setObjectName("rangeModeWidgetLayout")
        self.rangeModeWidgetLayout.setContentsMargins(0, 0, 0, 0)

        self.rangeRangeLabel = QtWidgets.QLabel(self.rangeModeWidget)
        self.rangeRangeLabel.setObjectName("rangeRangeLabel")
        self.rangeRangeLabel.setText("Range")
        self.rangeModeWidgetLayout.addWidget(self.rangeRangeLabel, 0, 0, 1, 1) 
        self.rangeValue = QtWidgets.QSpinBox(self.rangeModeWidget)
        self.rangeValue.setObjectName("rangeValue")
        self.rangeValue.setMaximum(9999)
        self.rangeValue.setValue(500)
        self.rangeModeWidgetLayout.addWidget(self.rangeValue, 0, 1, 1, 1)
        self.rangeClusterLabel = QtWidgets.QLabel(self.rangeModeWidget)
        self.rangeClusterLabel.setObjectName("rangeClusterLabel")
        self.rangeClusterLabel.setText("Number of clusters")
        self.rangeModeWidgetLayout.addWidget(self.rangeClusterLabel, 1, 0, 1, 1) 
        self.rangeClusterValue = QtWidgets.QSpinBox(self.rangeModeWidget)
        self.rangeClusterValue.setObjectName("rangeClusterValue")
        self.rangeClusterValue.setMaximum(9999)
        self.rangeClusterValue.setValue(7000)
        self.rangeModeWidgetLayout.addWidget(self.rangeClusterValue, 1, 1, 1, 1) 

        self.clusterLayout.addWidget(self.rangeModeWidget, 3, 0, 1, 2)

        spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.clusterLayout.addItem(spacerItem, 4, 0, 1, 1)

        self.inputLayout.addWidget(self.clusterGroupBox, 2, 1, 1, 1)

        self.tabs = QtWidgets.QTabWidget(self.splitter)
        self.tabs.setObjectName("tabs")

        self.outputSplitter = QtWidgets.QSplitter(self.splitter)
        self.outputSplitter.setObjectName("outputSplitter")
        self.outputSplitter.setOrientation(QtCore.Qt.Horizontal)
        self.outputSplitter.setHandleWidth(10)
        #self.outputSplitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter_h.png")+");}");
        policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        self.outputSplitter.setSizePolicy(policy)

        self.tabs.addTab(self.outputSplitter, "General")

        self.tree = QtWidgets.QTreeView(self.outputSplitter)
        policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.tree.setSizePolicy(policy)
        self.model = QtWidgets.QFileSystemModel(self.tree)
        self.tree.setModel(self.model)
        self.model.setNameFilters(["*.pdb", "*.ent"])
        self.model.setNameFilterDisables(False)
        self.tree.hideColumn(1)
        self.tree.hideColumn(2)
        self.tree.header().hide()
        self.tree.header().setSectionResizeMode(QtWidgets.QHeaderView.Stretch)
        self.tree.sortByColumn(3, QtCore.Qt.AscendingOrder)
        self.tree.setSortingEnabled(True)
        self.tree.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)

        self.structureLayoutWidget = QtWidgets.QWidget(self.outputSplitter)
        self.structureLayoutWidget.setObjectName("structureLayoutWidget")
        policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        self.structureLayoutWidget.setSizePolicy(policy)
        self.structureLayout = QtWidgets.QGridLayout(self.structureLayoutWidget)
        self.structureLayout.setObjectName("structureLayout")
        self.structureLayout.setContentsMargins(0, 0, 0, 0)

        self.browserLabel = QtWidgets.QLabel(self.structureLayoutWidget)
        self.browserLabel.setObjectName("browserLabel")
        self.browserLabel.setText("Model extracted and superposed")
        self.structureLayout.addWidget(self.browserLabel, 0, 0, 1, 7)        

        self.browser = QtWebEngineWidgets.QWebEngineView(self.structureLayoutWidget)
        self.browser.setObjectName("browser")
        self.browser.page().setBackgroundColor(QtCore.Qt.black)
        self.browser.setSizePolicy(policy)

        self.structureLayout.addWidget(self.browser, 1, 0, 1, 10)

        spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.structureLayout.addItem(spacerItem, 2, 0, 1, 1)

        self.representationLabel = QtWidgets.QLabel(self.structureLayoutWidget)
        self.representationLabel.setObjectName("representationLabel")
        self.representationLabel.setText("Representation")
        self.structureLayout.addWidget(self.representationLabel, 2, 1, 1, 1)
        self.representationValue = QtWidgets.QComboBox(self.structureLayoutWidget)
        self.representationValue.setObjectName("representationValue")
        self.representationValue.addItems(["cartoon" , "backbone", "licorice", "line"])
        self.structureLayout.addWidget(self.representationValue, 2, 2, 1, 1)        
        self.colorLabel = QtWidgets.QLabel(self.structureLayoutWidget)
        self.colorLabel.setObjectName("colorLabel")
        self.colorLabel.setText("Color")
        self.structureLayout.addWidget(self.colorLabel, 2, 3, 1, 1)
        self.colorValue = QtWidgets.QComboBox(self.structureLayoutWidget)
        self.colorValue.setObjectName("colorValue")
        self.colorValue.addItems(["secondary structure" , "residue", "chain id", "model"])
        self.colorValue.setMinimumContentsLength(5)
        self.structureLayout.addWidget(self.colorValue, 2, 4, 1, 1)
        self.line3 = QtWidgets.QFrame(self.structureLayoutWidget)
        self.line3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line3.setObjectName("line3")
        self.structureLayout.addWidget(self.line3, 2, 5, 1, 1)
        self.templateCheck = QtWidgets.QCheckBox(self.structureLayoutWidget)
        self.templateCheck.setObjectName("templateCheck")
        self.templateCheck.setText("Show template")
        self.structureLayout.addWidget(self.templateCheck, 2, 6, 1, 1)
        self.templateValue = QtWidgets.QComboBox(self.structureLayoutWidget)
        self.templateValue.setObjectName("templateValue")
        self.templateValue.addItems(["cartoon" , "backbone", "licorice", "line"])
        self.structureLayout.addWidget(self.templateValue, 2, 7, 1, 1)
        self.line5 = QtWidgets.QFrame(self.structureLayoutWidget)
        self.line5.setFrameShape(QtWidgets.QFrame.VLine)
        self.line5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line5.setObjectName("line5")
        self.structureLayout.addWidget(self.line5, 2, 8, 1, 1)
        self.saveButton = QtWidgets.QPushButton(self.structureLayoutWidget)
        self.saveButton.setObjectName("saveButton")
        self.saveButton.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
        self.structureLayout.addWidget(self.saveButton, 2, 9, 1, 1)

        self.templateBrowserLayoutWidget = QtWidgets.QWidget(self.outputSplitter)
        self.templateBrowserLayoutWidget.setObjectName("templateBrowserLayoutWidget")
        policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        self.templateBrowserLayoutWidget.setSizePolicy(policy)
        self.templateBrowserLayout = QtWidgets.QGridLayout(self.templateBrowserLayoutWidget)
        self.templateBrowserLayout.setObjectName("templateBrowserLayout")
        self.templateBrowserLayout.setContentsMargins(0, 0, 0, 0)

        self.templateBrowserLabel = QtWidgets.QLabel(self.templateBrowserLayoutWidget)
        self.templateBrowserLabel.setObjectName("templateBrowserLabel")
        self.templateBrowserLabel.setText("Template")
        self.templateBrowserLayout.addWidget(self.templateBrowserLabel, 0, 0, 1, 7)

        self.templateBrowser = QtWebEngineWidgets.QWebEngineView(self.templateBrowserLayoutWidget)
        self.templateBrowser.setObjectName("templateBrowser")
        self.templateBrowser.page().setBackgroundColor(QtCore.Qt.black)
        self.templateBrowser.setSizePolicy(policy)
        self.templateBrowserLayout.addWidget(self.templateBrowser, 1, 0, 1, 7)

        spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.templateBrowserLayout.addItem(spacerItem, 2, 0, 1, 1)

        self.representationTemplateLabel = QtWidgets.QLabel(self.templateBrowserLayoutWidget)
        self.representationTemplateLabel.setObjectName("representationTemplateLabel")
        self.representationTemplateLabel.setText("Representation")
        self.templateBrowserLayout.addWidget(self.representationTemplateLabel, 2, 1, 1, 1)
        self.representationTemplateValue = QtWidgets.QComboBox(self.templateBrowserLayoutWidget)
        self.representationTemplateValue.setObjectName("representationTemplateValue")
        self.representationTemplateValue.addItems(["cartoon" , "backbone", "licorice", "line"])
        self.templateBrowserLayout.addWidget(self.representationTemplateValue, 2, 2, 1, 1)        
        self.colorTemplateLabel = QtWidgets.QLabel(self.templateBrowserLayoutWidget)
        self.colorTemplateLabel.setObjectName("colorTemplateLabel")
        self.colorTemplateLabel.setText("Color")
        self.templateBrowserLayout.addWidget(self.colorTemplateLabel, 2, 3, 1, 1)
        self.colorTemplateValue = QtWidgets.QComboBox(self.templateBrowserLayoutWidget)
        self.colorTemplateValue.setObjectName("colorTemplateValue")
        self.colorTemplateValue.addItems(["secondary structure" , "residue", "chain id"])
        self.colorTemplateValue.setMinimumContentsLength(5)
        self.templateBrowserLayout.addWidget(self.colorTemplateValue, 2, 4, 1, 1)
        self.line4 = QtWidgets.QFrame(self.structureLayoutWidget)
        self.line4.setFrameShape(QtWidgets.QFrame.VLine)
        self.line4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line4.setObjectName("line4")
        self.templateBrowserLayout.addWidget(self.line4, 2, 5, 1, 1)
              
        self.saveButton2 = QtWidgets.QPushButton(self.structureLayoutWidget)
        self.saveButton2.setObjectName("saveButton2")
        self.saveButton2.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
        self.templateBrowserLayout.addWidget(self.saveButton2, 2, 6, 1, 1) 

        self.advancedWidget = QtWidgets.QWidget(self.tabs)
        self.tabs.addTab(self.advancedWidget, "Advanced")

        self.advancedWidget.setObjectName("advancedWidget")
        policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        self.advancedWidget.setSizePolicy(policy)

        self.advancedLayout = QtWidgets.QGridLayout(self.advancedWidget)
        self.advancedLayout.setObjectName("advancedLayout")
        self.advancedLayout.setContentsMargins(0, 0, 0, 0)
        
        self.textOutput = QtWidgets.QTextEdit(self.splitter)
        self.textOutput.setObjectName("textOutput")
        self.textOutput.setReadOnly(True)

        self.gridLayout.addWidget(self.splitter, 0, 0, 1, 1)